# combo - content management system
# Copyright (C) 2014-2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import requests

from django.conf import settings
from django.db import models
from django.utils.http import urlencode
from django.utils.translation import ugettext_lazy as _

from combo.data.models import CellBase
from combo.data.library import register_cell_class
from combo.utils import NothingInCacheException, sign_url



@register_cell_class
class RecentDocumentsCell(CellBase):
    template_name = 'combo/fargo/recent-documents-cell.html'

    class Meta:
        verbose_name = _('Recent Documents')

    def is_visible(self, user=None):
        if not user or user.is_anonymous():
            return False
        return super(RecentDocumentsCell, self).is_visible(user)

    def is_fargo_enabled(self):
        return hasattr(settings, 'KNOWN_SERVICES') and settings.KNOWN_SERVICES.get('fargo')

    def get_json(self, path, context):
        fargo_site = settings.KNOWN_SERVICES['fargo'].values()[0]
        fargo_url = fargo_site.get('url')
        if not fargo_url.endswith('/'):
            fargo_url += '/'
        url = fargo_url + path
        params = {}
        params['orig'] = fargo_site.get('orig')
        if context.get('user') and context['user'].is_authenticated():
            if context.get('request') and hasattr(context['request'], 'session') \
               and context['request'].session.get('mellon_session'):
                mellon = context['request'].session['mellon_session']
                params['NameID'] = mellon['name_id_content']
            elif hasattr(context['user'], 'email') and context['user'].email:
                params['email'] = context['user'].email
        url += '?' + urlencode(params)
        url = sign_url(url, fargo_site.get('secret'))
        response_json = requests.get(url,
                    headers={'accept': 'application/json'}).json()
        return response_json

    def render(self, context):
        if not context.get('synchronous'):
            raise NothingInCacheException()
        context.update(self.get_json('api/documents/recently-added', context))
        return super(RecentDocumentsCell, self).render(context)
